@@ -41,7 +41,7 @@ class Adapter(Trainer):
 
         self.schedule = schedule
 
-        orig_callbacks = [] if "callbacks" not in kwargs else kwargs["callbacks"]
+        orig_callbacks = [] if "callbacks" not in kwargs else kwargs.pop("callbacks")
 
         super().__init__(model=lang_module,
                          args=args,
@@ -74,7 +74,7 @@ class Adapter(Trainer):
             raise NotImplementedError()  # objective-dependent label smoothing is custom
             # loss = self.label_smoother(outputs, labels)
         else:
-            loss = self.schedule.compute_loss(outputs, labels)
+            loss = self.schedule.compute_loss(outputs, labels, inputs)
 
         mock_outputs = torch.tensor([-1, -1])
         return (loss, mock_outputs) if return_outputs else loss
@@ -95,7 +95,7 @@ class Adapter(Trainer):
 
         return out
 
-    def save_model(self, output_dir: Optional[str] = None) -> None:
+    def save_model(self, output_dir: Optional[str] = None, **kwargs) -> None:
         # HF native reload compatibility
         objectives_counter = {str(obj): 0 for obj in self.schedule.objectives["train"].values()}
 
